@@ -5,6 +5,9 @@ use std::path;
 
 use failure::ResultExt;
 use jsonfeed::Feed;
+use log::debug;
+use log::trace;
+use log::warn;
 use sitemap::writer::SiteMapWriter;
 
 use crate::cobalt_model;
@@ -19,7 +22,7 @@ use crate::pagination;
 struct Context {
     pub destination: path::PathBuf,
     pub source_files: cobalt_core::Source,
-    pub page_extensions: Vec<kstring::KString>,
+    pub page_extensions: Vec<liquid::model::KString>,
     pub include_drafts: bool,
     pub pages: cobalt_model::Collection,
     pub posts: cobalt_model::Collection,
@@ -159,14 +162,14 @@ pub fn build(config: Config) -> Result<()> {
 fn generate_collections_var(
     posts_data: &[liquid::model::Value],
     context: &Context,
-) -> (kstring::KString, liquid::model::Value) {
+) -> (liquid::model::KString, liquid::model::Value) {
     let mut posts_variable = context.posts.attributes();
     posts_variable.insert(
         "pages".into(),
         liquid::model::Value::Array(posts_data.to_vec()),
     );
     let global_collection: liquid::Object = vec![(
-        context.posts.slug.clone().into(),
+        context.posts.slug.clone(),
         liquid::model::Value::Object(posts_variable),
     )]
     .into_iter()
@@ -180,7 +183,7 @@ fn generate_collections_var(
 fn generate_doc(
     doc: &mut Document,
     context: &Context,
-    global_collection: (kstring::KString, liquid::model::Value),
+    global_collection: (liquid::model::KString, liquid::model::Value),
 ) -> Result<()> {
     // Everything done with `globals` is terrible for performance.  liquid#95 allows us to
     // improve this.
@@ -275,7 +278,7 @@ fn generate_pages(posts: Vec<Document>, documents: Vec<Document>, context: &Cont
             generate_doc(
                 &mut doc,
                 context,
-                generate_collections_var(&posts_data, &context),
+                generate_collections_var(&posts_data, context),
             )?;
         };
     }
@@ -312,7 +315,7 @@ fn generate_posts(posts: &mut Vec<Document>, context: &Context) -> Result<()> {
         generate_doc(
             post,
             context,
-            generate_collections_var(&simple_posts_data, &context),
+            generate_collections_var(&simple_posts_data, context),
         )?;
     }
 
@@ -355,7 +358,6 @@ fn parse_drafts(
         let rel_src = file_path
             .rel_path
             .strip_prefix(drafts_dir)
-            .ok()
             .expect("file was found under the root");
         let new_path = dir.join(&rel_src);
 
@@ -454,8 +456,7 @@ fn create_rss(
         .link(link.to_owned())
         .description(description.to_owned())
         .items(items)
-        .build()
-        .map_err(failure::err_msg)?;
+        .build();
 
     let rss_string = channel.to_string();
     trace!("RSS data: {}", rss_string);
@@ -538,9 +539,9 @@ pub fn classify_path<'s>(
     path: &relative_path::RelativePathBuf,
     pages: &'s cobalt_model::Collection,
     posts: &'s cobalt_model::Collection,
-    page_extensions: &[kstring::KString],
+    page_extensions: &[liquid::model::KString],
 ) -> Option<(&'s str, bool)> {
-    if ext_contains(&page_extensions, &path) {
+    if ext_contains(page_extensions, path) {
         if path.starts_with(&posts.dir) {
             return Some((posts.slug.as_str(), false));
         }
@@ -557,7 +558,7 @@ pub fn classify_path<'s>(
     }
 }
 
-fn ext_contains(extensions: &[kstring::KString], file: &relative_path::RelativePath) -> bool {
+fn ext_contains(extensions: &[liquid::model::KString], file: &relative_path::RelativePath) -> bool {
     if extensions.is_empty() {
         return true;
     }
