@@ -1,6 +1,8 @@
 use std::fmt;
 use std::path;
 
+use log::debug;
+use serde::Serialize;
 use serde_yaml;
 
 use crate::error::*;
@@ -17,8 +19,8 @@ use super::vwiki;
 pub struct Config {
     pub source: path::PathBuf,
     pub destination: path::PathBuf,
-    pub ignore: Vec<kstring::KString>,
-    pub page_extensions: Vec<kstring::KString>,
+    pub ignore: Vec<liquid::model::KString>,
+    pub page_extensions: Vec<liquid::model::KString>,
     pub include_drafts: bool,
     pub pages: collection::Collection,
     pub posts: collection::Collection,
@@ -70,7 +72,7 @@ impl Config {
 
         let site = site::Site::from_config(site);
 
-        let mut ignore: Vec<kstring::KString> = vec![".*".into(), "_*".into()];
+        let mut ignore: Vec<liquid::model::KString> = vec![".*".into(), "_*".into()];
         if let Ok(rel_dest) = path::Path::new(&destination).strip_prefix(&source) {
             let rel_dest = rel_dest.to_str().expect("started as a utf-8 string");
             if !rel_dest.is_empty() {
@@ -96,11 +98,14 @@ impl Config {
 
         let liquid = template::LiquidBuilder {
             includes_path,
-            theme: syntax_highlight.theme.clone(),
+            theme: syntax_highlight
+                .enabled
+                .then(|| syntax_highlight.theme.clone()),
         };
         let markdown = mark::MarkdownBuilder {
-            theme: syntax_highlight.theme.clone(),
-            syntax_highlight_enabled: syntax_highlight.enabled,
+            theme: syntax_highlight
+                .enabled
+                .then(|| syntax_highlight.theme.clone()),
         };
         let vimwiki = vwiki::VimwikiBuilder {
             theme: syntax_highlight.theme,
@@ -136,7 +141,7 @@ impl Default for Config {
 }
 
 impl fmt::Display for Config {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         let mut converted = serde_yaml::to_string(self).map_err(|_| fmt::Error)?;
         converted.drain(..4);
         write!(f, "{}", converted)
